@@ -286,11 +286,11 @@ class Attributes(dict):
         return self._idx
 
     @classmethod
-    def unpack(cls, data, negotiated):
+    def unpack(cls, data, direction, negotiated):
         if cls.cached and data == cls.previous:
             return cls.cached
 
-        attributes = cls().parse(data, negotiated)
+        attributes = cls().parse(data, direction, negotiated)
 
         if Attribute.CODE.INTERNAL_TREAT_AS_WITHDRAW in attributes:
             return attributes
@@ -319,7 +319,7 @@ class Attributes(dict):
             length = ordinal(data[2])
             return flag, attr, data[3 : length + 3]
 
-    def parse(self, data, negotiated):
+    def parse(self, data, direction, negotiated):
         if not data:
             return self
 
@@ -363,16 +363,16 @@ class Attributes(dict):
                 % (Attribute.CODE.names.get(aid, 'unset'), flag, aid),
                 'parser',
             )
-            return self.parse(left, negotiated)
+            return self.parse(left, direction, negotiated)
 
         # handle the attribute if we know it
         if Attribute.registered(aid, flag):
             if length == 0 and aid not in self.VALID_ZERO:
                 self.add(TreatAsWithdraw(aid))
-                return self.parse(left, negotiated)
+                return self.parse(left, direction, negotiated)
 
             try:
-                decoded = Attribute.unpack(aid, flag, attribute, negotiated)
+                decoded = Attribute.unpack(aid, flag, attribute, direction, negotiated)
             except IndexError as exc:
                 if aid in self.TREAT_AS_WITHDRAW:
                     decoded = TreatAsWithdraw(aid)
@@ -386,7 +386,7 @@ class Attributes(dict):
                 else:
                     raise exc
             self.add(decoded)
-            return self.parse(left, negotiated)
+            return self.parse(left, direction, negotiated)
 
         # XXX: FIXME: we could use a fallback function here like capability
 
@@ -405,14 +405,14 @@ class Attributes(dict):
                     % (Attribute.CODE.names.get(aid, 'unset'), flag, aid),
                     'parser',
                 )
-                return self.parse(left, negotiated)
+                return self.parse(left, direction, negotiated)
             # XXX: Check if we are missing any
             logger.debug(
                 'invalid flag for attribute %s (flag 0x%02X, aid 0x%02X) unspecified (should not happen)'
                 % (Attribute.CODE.names.get(aid, 'unset'), flag, aid),
                 'parser',
             )
-            return self.parse(left, negotiated)
+            return self.parse(left, direction, negotiated)
 
         # it is an unknown transitive attribute we need to pass on
         if flag & Attribute.Flag.TRANSITIVE:
@@ -422,11 +422,11 @@ class Attributes(dict):
             except IndexError:
                 decoded = TreatAsWithdraw(aid)
             self.add(decoded, attribute)
-            return self.parse(left, negotiated)
+            return self.parse(left, direction, negotiated)
 
         # it is an unknown non-transitive attribute we can ignore.
         logger.debug('ignoring unknown non-transitive attribute (flag 0x%02X, aid 0x%02X)' % (flag, aid), 'parser')
-        return self.parse(left, negotiated)
+        return self.parse(left, direction, negotiated)
 
     def merge_attributes(self):
         as2path = self[Attribute.CODE.AS_PATH]
